@@ -12,7 +12,7 @@ impl<T> Join<T> where T: Send+'static {
   pub fn new() -> Self {
     Self { tasks: vec![] }
   }
-  pub fn push<F>(&mut self, future: F) -> () where F: Future<Output=Result<T,Error>>+Send+'static {
+  pub fn push<F>(&mut self, future: F) where F: Future<Output=Result<T,Error>>+Send+'static {
     self.tasks.push(spawn(future));
   }
   // todo: configurable amount of parallelism
