@@ -22,7 +22,7 @@ pub struct Build {
 impl Build {
   fn ext(&self) -> Self {
     Self {
-      range: self.range.clone(),
+      range: self.range,
       level: 0,
       count: 0,
     }
@@ -289,7 +289,7 @@ macro_rules! impl_tree {
       pub fn build<'a>(fields: Arc<SetupFields>,
       inserts: &[(($(Coord<$T>),+),InsertValue<'a,($(Coord<$T>),+),V>)],
       next_tree: &mut TreeId)
-      -> (Option<TreeRef<($(Coord<$T>),+)>>,HashMap<TreeId,Arc<Mutex<$Tree<$($T),+,V>>>>) {
+      -> (Option<TreeRef<($(Coord<$T>),+)>>,CreateTrees<$Tree<$($T),+,V>>) {
         if inserts.is_empty() { return (None, HashMap::new()) }
         let mut mstate = $MState {
           fields,
@@ -381,7 +381,7 @@ macro_rules! impl_tree {
       fn query<S>(&mut self, trees: Arc<Mutex<TreeFile<S,Self,($(Coord<$T>),+),V>>>,
         bbox: &(($($T),+),($($T),+)), fields: Arc<SetupFields>,
         root_index: usize, root_id: TreeId,
-      ) -> Arc<Mutex<QStream<($(Coord<$T>),+),V>>> where S: RA {
+      ) -> QStream<($(Coord<$T>),+),V> where S: RA {
         let istate = (
           bbox.clone(),
           vec![], // queue
@@ -390,7 +390,7 @@ macro_rules! impl_tree {
           Arc::clone(&trees),
           Arc::clone(&fields)
         );
-        Arc::new(Mutex::new(Box::new(unfold(istate, async move |mut state| {
+        Box::new(unfold(istate, async move |mut state| {
           let bbox = &state.0;
           let queue = &mut state.1;
           let cursors = &mut state.2;
@@ -480,7 +480,7 @@ macro_rules! impl_tree {
               },
             }
           }
-        }))))
+        }))
       }
       async fn remove<S>(&mut self, xids: Arc<Mutex<HashMap<V::Id,($(Coord<$T>),+)>>>)
       -> (Option<(Vec<(($(Coord<$T>),+),V)>,Vec<TreeRef<($(Coord<$T>),+)>>)>,Vec<TreeId>) where S: RA {
@@ -581,16 +581,17 @@ macro_rules! impl_tree {
   (usize,usize,usize,usize,usize,usize,usize,usize),(None,None,None,None,None,None,None,None),8
 ];
 
+type CreateTrees<T> = HashMap<TreeId,Arc<Mutex<T>>>;
+
 #[async_trait::async_trait]
 pub trait Tree<P,V>: Send+Sync+ToBytes+FromBytes+CountBytes+std::fmt::Debug+'static
 where P: Point, V: Value {
   fn empty() -> Self;
   fn build<'a>(fields: Arc<SetupFields>, rows: &[(P,InsertValue<'a,P,V>)], next_tree: &mut TreeId)
-    -> (Option<TreeRef<P>>,HashMap<TreeId,Arc<Mutex<Self>>>) where Self: Sized;
+    -> (Option<TreeRef<P>>,CreateTrees<Self>) where Self: Sized;
   fn list(&mut self) -> (Vec<(P,V)>,Vec<TreeRef<P>>);
   fn query<S>(&mut self, trees: Arc<Mutex<TreeFile<S,Self,P,V>>>, bbox: &P::Bounds,
-    fields: Arc<SetupFields>, root_index: usize, root_id: TreeId)
-    -> Arc<Mutex<QStream<P,V>>> where S: RA;
+    fields: Arc<SetupFields>, root_index: usize, root_id: TreeId) -> QStream<P,V> where S: RA;
   async fn remove<S>(&mut self, ids: Arc<Mutex<HashMap<V::Id,P>>>)
     -> (Option<(Vec<(P,V)>,Vec<TreeRef<P>>)>,Vec<TreeId>) where S: RA;
 }
@@ -681,7 +682,7 @@ where P: Point, V: Value, T: Tree<P,V>, S: RA {
       // TODO: remove the delete when found
       let trees = Arc::clone(&self.trees);
       let xids = Arc::clone(&ids);
-      let id = r.id.clone();
+      let id = r.id;
       let xfields = Arc::clone(&fields);
       join.push(async move {
         let mut refs = vec![id];
